# coding=utf-8
r"""
This code was generated by
\ / _    _  _|   _  _
 | (_)\/(_)(_|\/| |(/_  v1.0.0
      /       /
"""

from tests import IntegrationTestCase
from tests.holodeck import Request
from twilio.base import serialize
from twilio.base.exceptions import TwilioException
from twilio.http.response import Response


class InteractionChannelInviteTestCase(IntegrationTestCase):

    def test_create_request(self):
        self.holodeck.mock(Response(500, ''))

        with self.assertRaises(TwilioException):
            self.client.flex_api.v1.interaction("KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                   .channels("UOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                   .invites.create(routing={})

        values = {'Routing': serialize.object({}), }

        self.holodeck.assert_has_request(Request(
            'post',
            'https://flex-api.twilio.com/v1/Interactions/KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX/Channels/UOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX/Invites',
            data=values,
        ))

    def test_create_response(self):
        self.holodeck.mock(Response(
            201,
            '''
            {
                "sid": "KGaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                "channel_sid": "UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1",
                "interaction_sid": "KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                "routing": {
                    "properties": {
                        "account_sid": "ACaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "workspace_sid": "WSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "sid": "WTaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "date_created": 1634845217,
                        "date_updated": 1634845217,
                        "attributes": "{\\"customerAddress\\":\\"customer email address\\",\\"conversationSid\\":\\"UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1\\",\\"customerName\\":\\"customer name\\"}",
                        "assignment_status": "pending",
                        "workflow_sid": "WWaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "workflow_name": "Default Fifo Workflow",
                        "queue_sid": "WQaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "queue_name": "Sample Queue",
                        "priority": 0,
                        "age": 0,
                        "reason": null,
                        "timeout": 86400,
                        "assignmentCounter": 0,
                        "task_channel_sid": "TCaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "task_channel_unique_name": "default",
                        "routing_target": "WKaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "task_queue_entered_date": 1634845217,
                        "age_in_queue": 0,
                        "addons": "{}"
                    }
                },
                "url": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/Channels/UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1/Invites/KGaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
            }
            '''
        ))

        actual = self.client.flex_api.v1.interaction("KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                        .channels("UOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                        .invites.create(routing={})

        self.assertIsNotNone(actual)

    def test_list_request(self):
        self.holodeck.mock(Response(500, ''))

        with self.assertRaises(TwilioException):
            self.client.flex_api.v1.interaction("KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                   .channels("UOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                   .invites.list()

        self.holodeck.assert_has_request(Request(
            'get',
            'https://flex-api.twilio.com/v1/Interactions/KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX/Channels/UOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX/Invites',
        ))

    def test_read_response(self):
        self.holodeck.mock(Response(
            200,
            '''
            {
                "invites": [
                    {
                        "sid": "KGaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1",
                        "channel_sid": "UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1",
                        "interaction_sid": "KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "routing": {
                            "properties": {
                                "account_sid": "ACaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "workspace_sid": "WSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "sid": "WTaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "date_created": 1634845217,
                                "date_updated": 1634845217,
                                "attributes": "{\\"customerAddress\\":\\"customer email address\\",\\"conversationSid\\":\\"UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1\\",\\"customerName\\":\\"customer name\\"}",
                                "assignment_status": "pending",
                                "workflow_sid": "WWaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "workflow_name": "Default Fifo Workflow",
                                "queue_sid": "WQaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "queue_name": "Sample Queue",
                                "priority": 0,
                                "age": 0,
                                "reason": null,
                                "timeout": 86400,
                                "assignmentCounter": 0,
                                "task_channel_sid": "TCaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "task_channel_unique_name": "default",
                                "routing_target": "WKaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "task_queue_entered_date": 1634845217,
                                "age_in_queue": 0,
                                "addons": "{}"
                            }
                        },
                        "url": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/Channels/UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1/Invites/KGaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1"
                    },
                    {
                        "sid": "KGaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa2",
                        "channel_sid": "UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1",
                        "interaction_sid": "KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "routing": {
                            "properties": {
                                "account_sid": "ACaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "workspace_sid": "WSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "sid": "WTaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "date_created": 1634845217,
                                "date_updated": 1634845217,
                                "attributes": "{\\"customerAddress\\":\\"customer email address\\",\\"conversationSid\\":\\"UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1\\",\\"customerName\\":\\"customer name\\"}",
                                "assignment_status": "pending",
                                "workflow_sid": "WWaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "workflow_name": "Default Fifo Workflow",
                                "queue_sid": "WQaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "queue_name": "Sample Queue",
                                "priority": 0,
                                "age": 0,
                                "reason": null,
                                "timeout": 86400,
                                "assignmentCounter": 0,
                                "task_channel_sid": "TCaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "task_channel_unique_name": "default",
                                "routing_target": "WKaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                "task_queue_entered_date": 1634845217,
                                "age_in_queue": 0,
                                "addons": "{}"
                            }
                        },
                        "url": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/Channels/UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1/Invites/KGaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa2"
                    }
                ],
                "meta": {
                    "page": 0,
                    "page_size": 50,
                    "first_page_url": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/Channels/UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1/Invites?PageSize=50&Page=0",
                    "previous_page_url": null,
                    "url": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/Channels/UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa1/Invites?PageSize=50&Page=0",
                    "next_page_url": null,
                    "key": "invites"
                }
            }
            '''
        ))

        actual = self.client.flex_api.v1.interaction("KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                        .channels("UOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX") \
                                        .invites.list()

        self.assertIsNotNone(actual)
